#[non_exhaustive]pub struct CreateExternalAccountKeyRequest {
pub parent: String,
pub external_account_key: Option<ExternalAccountKey>,
/* private fields */
}Expand description
Creates a new ExternalAccountKey in a given project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this external_account_key will be created. Format: projects/[project_id]/locations/[location]. At present only the “global” location is supported.
external_account_key: Option<ExternalAccountKey>Required. The external account key to create. This field only exists to future-proof the API. At present, all fields in ExternalAccountKey are output only and all values are ignored. For the purpose of the CreateExternalAccountKeyRequest, set it to a default/empty value.
Implementations
Sourceimpl CreateExternalAccountKeyRequest
impl CreateExternalAccountKeyRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_external_account_key<T>(self, v: T) -> Selfwhere
T: Into<ExternalAccountKey>,
pub fn set_external_account_key<T>(self, v: T) -> Selfwhere
T: Into<ExternalAccountKey>,
Sets the value of external_account_key.
Example
ⓘ
use google_cloud_security_publicca_v1::model::ExternalAccountKey;
let x = CreateExternalAccountKeyRequest::new().set_external_account_key(ExternalAccountKey::default()/* use setters */);Sourcepub fn set_or_clear_external_account_key<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExternalAccountKey>,
pub fn set_or_clear_external_account_key<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExternalAccountKey>,
Sets or clears the value of external_account_key.
Example
ⓘ
use google_cloud_security_publicca_v1::model::ExternalAccountKey;
let x = CreateExternalAccountKeyRequest::new().set_or_clear_external_account_key(Some(ExternalAccountKey::default()/* use setters */));
let x = CreateExternalAccountKeyRequest::new().set_or_clear_external_account_key(None::<ExternalAccountKey>);Trait Implementations
Sourceimpl Clone for CreateExternalAccountKeyRequest
impl Clone for CreateExternalAccountKeyRequest
Sourcefn clone(&self) -> CreateExternalAccountKeyRequest
fn clone(&self) -> CreateExternalAccountKeyRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateExternalAccountKeyRequest
impl Default for CreateExternalAccountKeyRequest
Sourcefn default() -> CreateExternalAccountKeyRequest
fn default() -> CreateExternalAccountKeyRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateExternalAccountKeyRequest
impl PartialEq for CreateExternalAccountKeyRequest
Sourcefn eq(&self, other: &CreateExternalAccountKeyRequest) -> bool
fn eq(&self, other: &CreateExternalAccountKeyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateExternalAccountKeyRequest